@@ -91,18 +91,39 @@ struct _GnomeFontClass {
 	GObjectClass parent_class;
 };
 
-/* PostScript encapsulated */
+GnomeFont *gnome_font_face_get_font_full (GnomeFontFace *face, gdouble size, gdouble *affine);
+
+/* Embeddable PostScript object */
+
 typedef struct _GFPSObject GFPSObject;
 
 struct _GFPSObject {
+	/* Our face (NB referenced) */
+	GnomeFontFace *face;
+	/* Resident face name, if any */
+	guchar *residentname;
+	/* Name of final font (i.e. findfont argument) */
+	guchar *encodedname;
+	/* 1 or 2 byte encoding
+	 * This will be set according to total number of
+	 * glyphs in font, as we cannot know the number
+	 * of glyphs used initially */
+	gint encodedbytes;
+	/* Number of glyphs in face */
+	gint num_glyphs;
+	/* Used glyph bit array */
+	guint32 *glyphs;
+	/* Buffer values */
 	gint bufsize;
 	gint length;
-	guchar * buf;
-	guchar * encodedname;
-	gint encodedbytes;
+	guchar *buf;
 };
 
-GFPSObject * gnome_font_face_create_ps_object (const GnomeFontFace * face);
+GFPSObject *gnome_font_face_pso_new (GnomeFontFace *face, guchar *residentname);
+/* Mark glyph as used in internal bit array */
+void gnome_font_face_pso_mark_glyph (GFPSObject *pso, gint glyph);
+void gnome_font_face_pso_free (GFPSObject *pso);
+void gnome_font_face_pso_ensure_buffer (GFPSObject *pso);
 
 /* Private face loader */
 
@@ -117,6 +138,34 @@ gboolean gff_load (GnomeFontFace *face);
 
 const guchar *gnome_font_unsized_get_glyph_name (const GnomeFontFace *face);
 
+
+/* ---- gnome-rfont-stuff --- */
+/*
+ * Rendering flags
+ *
+ * Look into gnome-pgl.h for more meaningful definitions
+ */
+
+#define GNOME_RFONT_RENDER_DEFAULT 0
+
+#define gnome_rfont_render_pgl_rgb8 gnome_pgl_render_rgb8
+#define gnome_rfont_render_pgl_rgba8 gnome_pgl_render_rgba8
+
+
+void gnome_rfont_render_glyph_rgba8 (GnomeRFont *rfont, gint glyph,
+							  guint32 rgba,
+							  gdouble x, gdouble y,
+							  guchar * buf,
+							  gint width, gint height, gint rowstride,
+							  guint flags);
+
+void gnome_rfont_render_glyph_rgb8 (GnomeRFont *rfont, gint glyph,
+							 guint32 rgba,
+							 gdouble x, gdouble y,
+							 guchar * buf,
+							 gint width, gint height, gint rowstride,
+							 guint flags);
+
 G_END_DECLS
 
 #endif
