@@ -1,28 +1,31 @@
-#define __GPA_REFERENCE_C__
-
-/*                                                            
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/*
+ *  gpa-reference.c:
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public License
+ *  as published by the Free Software Foundation; either version 2 of
+ *  the License, or (at your option) any later version.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Library General Public License for more details.
  *
- * Authors :
- *   Chema Celorio <chema@celorio.com>
- *   Lauris Kaplinski <lauris@ximian.com>
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * Copyright (C) 2000-2001 Ximian, Inc. and Jose M. Celorio
+ *  Authors :
+ *    Jose M. Celorio <chema@ximian.com>
+ *    Lauris Kaplinski <lauris@ximian.com>
+ *
+ *  Copyright (C) 2000-2001 Ximian, Inc. and Jose M. Celorio
  *
  */
 
+#define __GPA_REFERENCE_C__
+
 #include <string.h>
 
 #include "gpa-reference.h"
@@ -148,8 +151,10 @@ gpa_reference_verify (GPANode *node)
 
 	reference = GPA_REFERENCE (node);
 
-	if (!reference->ref) return FALSE;
-	if (!gpa_node_verify (reference->ref)) return FALSE;
+	if (!reference->ref)
+		return FALSE;
+	if (!gpa_node_verify (reference->ref))
+		return FALSE;
 
 	return TRUE;
 }
