@@ -1,18 +1,33 @@
-#define __GP_TRANSPORT_LPR_C__
-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * LPR transport destination
+ *  gp-transport-lpr.c:
  *
- * Authors:
- *   Raph Levien (raph@acm.org)
- *   Miguel de Icaza (miguel@kernel.org)
- *   Lauris Kaplinski <lauris@ximian.com>
- *   Chema Celorio (chema@celorio.com)
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public License
+ *  as published by the Free Software Foundation; either version 2 of
+ *  the License, or (at your option) any later version.
  *
- * Copyright (C) 1999-2001 Ximian, Inc. and authors
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *  Authors:
+ *    Raph Levien <raph@acm.org>
+ *    Miguel de Icaza <miguel@kernel.org>
+ *    Lauris Kaplinski <lauris@ximian.com>
+ *    Chema Celorio <chema@celorio.com>
+ *
+ *  Copyright (C) 1999-2001 Ximian Inc. and authors
  *
  */
 
+#define __GP_TRANSPORT_LPR_C__
+
 #include <libgnomeprint/gnome-print.h>
 #include "gp-transport-lpr.h"
 
@@ -104,7 +119,7 @@ gp_transport_lpr_construct (GnomePrintTransport *transport)
 
 	tlpr = GP_TRANSPORT_LPR (transport);
 
-	value = gpa_node_get_path_value (transport->config, "Settings.Transport.Backend.Printer");
+	value = gnome_print_config_get (transport->config, "Settings.Transport.Backend.Printer");
 
 	if (value && *value) {
 		tlpr->printer = value;
@@ -128,13 +143,14 @@ gp_transport_lpr_open (GnomePrintTransport *transport)
 	}
 
 	tlpr->pipe = popen (command, "w");
-	g_free (command);
 
 	if (tlpr->pipe == NULL) {
-		g_warning ("Opening 'lpr -P%s' for output failed", tlpr->printer);
+		g_warning ("Opening '%s' for output failed", command);
+		g_free (command);
 		return GNOME_PRINT_ERROR_UNKNOWN;
 	}
-
+	
+	g_free (command);
 	return GNOME_PRINT_OK;
 }
 
